AiAppBridgeH5Adapter class
Constructors
- AiAppBridgeH5Adapter({required String id, required String source, required AiAppBridgeH5Evaluator evaluateJavascript, required bool isVisible(), AiAppBridgeH5MetadataProvider? metadata})
-
const
Properties
- evaluateJavascript → AiAppBridgeH5Evaluator
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isVisible → bool Function()
-
final
- metadata → AiAppBridgeH5MetadataProvider?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited